@@ -18,7 +18,13 @@ subscription_schema = [
     "default_payment_method",
     "default_source",
     "default_tax_rate",
-    "discount",
+    "discount_coupon_amount_off",
+    "discount_coupon_duration_in_months",
+    "discount_coupon_name",
+    "discount_customer",
+    "discount_promotion_code",
+    "discount_subscription",
+    "discount_id",
     "ended_at",
     "id",
     "items_data_plan_amount_decimal",
